import {NostrSmtpServer} from "./smtpServer.ts";
import {HttpServer} from "./httpServer.ts";
import {createClient as createDB} from "@libsql/client/sqlite3";
import "@std/dotenv/load";

const requiredEnvVars = [
  "BASE_DOMAIN",
  "DB_URL",
  "PUBLIC_API_BASE_URL",
  "MASTER_NSEC",
];

for (const envVar of requiredEnvVars) {
  if (!Deno.env.has(envVar)) {
    throw new Error(`${envVar} is not set`);
  }
}

export const db = createDB({
  url: Deno.env.get("DB_URL")!,
});

new NostrSmtpServer(
  db,
  parseInt(
    Deno.env.get("SMTP_PORT") || "6587",
  ),
);
new HttpServer(
  db,
  parseInt(
    Deno.env.get("HTTP_PORT") || "3000",
  ),
);
